@@ -93,6 +93,8 @@ highest_concentration <- function(df, value, lon = lon, lat = lat,
                                   grid_distance = 25, gh_precision = 6,
                                   display_progress = TRUE){
 
+  df <- as.data.frame(df)
+
   value_nm <- deparse(substitute(value))
   lon_nm <- deparse(substitute(lon))
   lat_nm <- deparse(substitute(lat))
@@ -117,7 +119,8 @@ highest_concentration <- function(df, value, lon = lon, lat = lat,
     warning(nrows1 - nrow(df), " NAs detected in ", value_nm, ". Rows with NAs removed.", call. = FALSE)
   }
 
-  # Add geohash (length 5 is 4.89km x 4.89km; length 6 is 1.22 x 0.61km; length 7 is 153m x 153m; length 8 is 38m x 19m)
+  # Add geohash (length 5 is 4.89km x 4.89km; length 6 is 1.22 x 0.61km;
+  # length 7 is 153m x 153m; length 8 is 38m x 19m)
   df[["geohash"]] <- geohashTools::gh_encode(latitude = df[[lat_nm]],
                                              longitude = df[[lon_nm]],
                                              precision = gh_precision)
@@ -274,7 +277,7 @@ neighborhood_gh_search <- function(hc, highest_geohash = 1, max.call = 1000, ver
   # Function to minimize
   csa <- function(x){
     df <- data.frame(lon = x[1], lat = x[2])
-    -concentration(df, pts_remaining, valueconc, display_progress = FALSE)$concentration[1]
+    -concentration(df, pts_remaining, valueconc, radius = radius, display_progress = FALSE)$concentration[1]
   }
 
   gsa_lst <- vector("list", length(geohash))
@@ -299,7 +302,9 @@ neighborhood_gh_search <- function(hc, highest_geohash = 1, max.call = 1000, ver
                        control = list(verbose = verbose,
                                       max.call = max.call))
 
-    df <- data.frame(highest_concentration = -sa$value, lon = sa$par[1], lat = sa$par[2],
+    df <- data.frame(highest_concentration = -sa$value,
+                     lon = sa$par[1],
+                     lat = sa$par[2],
                      geohash = geohash[i])
     gsa_lst[[i]] <- df
   }
